NAME

Protobuf - High-performance Google Protocol Buffers implementation

VERSION

version 0.04

SYNOPSIS

use Protobuf;

# Load descriptors (typically done by generated code)
my $pool = Protobuf::DescriptorPool->generated_pool;

# Example: Create a new message (assuming My::Message is generated)
# my $msg = My::Message->new({ name => 'foo', value => 123 });

# Serialize
# my $binary = $msg->serialize;

# Parse
# my $decoded = My::Message->parse($binary);

DESCRIPTION

This module provides a Perl interface to Google Protocol Buffers, leveraging the high-performance C library upb. The implementation aims for speed, efficiency, and close alignment with the features and behaviors of the official Python UPB-based extension.

SEE ALSO

Protobuf::Message, Protobuf::DescriptorPool, Protobuf::Arena

AUTHOR

C.J. Collier <cjac@google.com>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Google LLC.

This is free software; you can redistribute it and/or modify it under the terms of the BSD 3-Clause License.